@@ -4,7 +4,7 @@
  * Implementation of the part of the TclCurl extension that deals with libcurl's
  * 'multi' interface.
  *
- * Copyright (c)2002-2006 Andrs Garca Garca.
+ * Copyright (c)2002-2007 Andres Garcia Garcia.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -194,6 +194,10 @@ curlMultiObjCmd (ClientData clientData, Tcl_Interp *interp,
 /*            fprintf(stdout,"Multi auto transfer\n");*/
             curlMultiAutoTransfer(interp,curlMultiData,objc,objv);
             break;
+        case 7:
+/*            fprintf(stdout,"Multi configure\n");*/
+            curlMultiConfigTransfer(interp,curlMultiData,objc,objv);
+            break;            
     }
     return TCL_OK;
 }
@@ -688,11 +692,123 @@ curlMultiAutoTransfer(Tcl_Interp *interp, struct curlMultiObjData *curlMultiData
     return TCL_OK;
 }
 
+/*----------------------------------------------------------------------
+ *
+ * curlMultiConfigTrasnfer --
+ *  This procedure is invoked by the user command 'configure', it reads 
+ *  the options passed by the user to configure a multi handle.
+ *
+ * Parameters:
+ *  The usual Tcl command parameters.
+ *
+ * Results:
+ *	Standard Tcl return code.
+ *----------------------------------------------------------------------
+ */
+
+int
+curlMultiConfigTransfer(Tcl_Interp *interp, struct curlMultiObjData *curlMultiData,
+        int objc,Tcl_Obj *CONST objv[]) {
+    int            tableIndex;
+    int            i,j;
+
+    Tcl_Obj       *resultPtr;
+    char           errorMsg[500];
+
+    for(i=2,j=3;i<objc;i=i+2,j=j+2) {
+        if (Tcl_GetIndexFromObj(interp, objv[i], multiConfigTable, "option", 
+                TCL_EXACT, &tableIndex)==TCL_ERROR) {
+            return TCL_ERROR;
+        }
+        if (i==objc-1) {
+            snprintf(errorMsg,500,"Empty value for %s",multiConfigTable[tableIndex]);
+            resultPtr=Tcl_NewStringObj(errorMsg,-1);
+            Tcl_SetObjResult(interp,resultPtr);            
+            return TCL_ERROR;
+        }
+        if (curlMultiSetOpts(interp,curlMultiData,objv[j],tableIndex)==TCL_ERROR) {
+            return TCL_ERROR;
+        }
+    }
+    return TCL_OK;
+}
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * curlMultiSetOpts --
+ *
+ *	This procedure takes care of setting the transfer options.
+ *
+ *  Parameter:
+ *      interp: Pointer to the interpreter we are using.
+ *      curlMultiHandle: the curl handle for which the option is set.
+ *      objv: A pointer to the object where the data to set is stored.
+ *      tableIndex: The index of the option in the options table.
+ *
+ * Results:
+ *  A standard Tcl result.
+ *----------------------------------------------------------------------
+ */
+int
+curlMultiSetOpts(Tcl_Interp *interp, struct curlMultiObjData *curlMultiData,
+        Tcl_Obj *CONST objv,int tableIndex) {
+
+    switch(tableIndex) {
+        case 0:
+            if (SetMultiOptLong(interp,curlMultiData->mcurl,
+                    CURLMOPT_PIPELINING,tableIndex,objv)) {
+                return TCL_ERROR;
+            }
+            break;
+    }
+    return TCL_OK;
+}
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * SetMultiOptLong --
+ *
+ *	Set the curl options that require a long
+ *
+ *  Parameter:
+ *      interp: The interpreter we are working with.
+ *      curlMultiHandle: and the multi curl handle
+ *      opt: the option to set
+ *      tclObj: The Tcl with the value for the option.
+ *
+ * Results:
+ *  0 if all went well.
+ *  1 in case of error.
+ *----------------------------------------------------------------------
+ */
+int
+SetMultiOptLong(Tcl_Interp *interp,CURLM *curlMultiHandle,CURLMoption opt,
+        int tableIndex,Tcl_Obj *tclObj) {
+    long        longNumber;
+    char        *parPtr;
+
+    if (Tcl_GetLongFromObj(interp,tclObj,&longNumber)) {
+        parPtr=curlstrdup(Tcl_GetString(tclObj));
+        curlErrorSetOpt(interp,multiConfigTable,tableIndex,parPtr);
+        Tcl_Free(parPtr);
+        return 1;
+    }
+    if (curl_multi_setopt(curlMultiHandle,opt,longNumber)) {
+        parPtr=curlstrdup(Tcl_GetString(tclObj));
+        curlErrorSetOpt(interp,multiConfigTable,tableIndex,parPtr);
+        Tcl_Free(parPtr);
+        return 1;
+    }
+    return 0;
+}
+
 /*----------------------------------------------------------------------
  *
  * curlEventSetup --
  *
- *	This function is invoked by Tcl just after curlMultiAutoTransfer and
+ *  This function is invoked by Tcl just after curlMultiAutoTransfer and
  *  then every time just before curlEventCheck, I only use to set the
  *  maximun time without checking for events
  *
