@@ -4,7 +4,7 @@
  * Header file for the part of the TclCurl extension that deals with libcurl's
  * 'multi' interface.
  *
- * Copyright (c) 2002-2006 Andrs Garca Garca.
+ * Copyright (c) 2002-2007 Andrs Garca Garca.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -52,9 +52,15 @@ static CONST char *multiCommandTable[] = {
     "getinfo",
     "active",
     "auto",
+    "configure",
     (char *) NULL
 };
 
+static CONST char *multiConfigTable[] = {
+    "-pipelining",
+    (char *)NULL
+};
+
 char *curlCreateMultiObjCmd (Tcl_Interp *interp,struct curlMultiObjData *curlMultiData);
 
 int Tclcurl_MultiInit (Tcl_Interp *interp);
@@ -90,8 +96,12 @@ void curlEasyHandleListAdd(struct curlMultiObjData *multiDataPtr,CURL *easyHandl
 void curlEasyHandleListRemove(struct curlMultiObjData *multiDataPtr,CURL *easyHandle);
 char *curlGetEasyName(struct curlMultiObjData *multiDataPtr,CURL *easyHandle);
 
-
 int curlMultiAutoTransfer(Tcl_Interp *interp, struct curlMultiObjData *curlMultiData, int objc,Tcl_Obj *CONST objv[]);
+int curlMultiSetOpts(Tcl_Interp *interp, struct curlMultiObjData *curlMultiData,Tcl_Obj *CONST objv,int tableIndex);
+int SetMultiOptLong(Tcl_Interp *interp,CURLM *curlMultiHandle,CURLMoption opt,
+        int tableIndex,Tcl_Obj *tclObj);
+
+int curlMultiConfigTransfer(Tcl_Interp *interp, struct curlMultiObjData *curlMultiData, int objc,Tcl_Obj *CONST objv[]);
 
 void curlEventSetup(ClientData clientData, int flags);
 
