@@ -4,7 +4,7 @@
  * Header file for the TclCurl extension to enable Tcl interpreters
  * to access libcurl.
  *
- * Copyright (c) 2001-2006 Andrs Garca Garca.
+ * Copyright (c) 2001-2007 Andrs Garca Garca.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -42,7 +42,7 @@ extern "C" {
 #define TCL_STORAGE_CLASS DLLEXPORT
 #endif
 
-#define TclCurlVersion "0.15.3"
+#define TclCurlVersion "7.16.2"
 
 /*
  * This struct will contain the data of a transfer if the user wants
@@ -131,14 +131,12 @@ struct curlObjData {
     struct curl_slist      *http200aliases;
     char                   *command;
     char                   *netrcfile;
-    char                   *sourceUrl;
-    char                   *sourceUserPwd;
-    struct curl_slist      *sourcePreQuote;
-    struct curl_slist      *sourceQuote;
-    struct curl_slist      *sourcePostQuote;
     char                   *ftpAccount;
     int                     anyAuthFlag;
     char                   *cookieList;
+    char                   *ftpAlternativeToUser;
+    char                   *sshpublickeyfile;
+    char                   *sshprivatekeyfile;
 };
 
 struct shcurlObjData {
@@ -202,6 +200,12 @@ static CONST char *optionTable[] = {
     "CURLOPT_FTP_ACCOUNT",    "CURLOPT_IGNORE_CONTENT_LENGTH",
     "CURLOPT_COOKIELIST",     "CURLOPT_FTP_SKIP_PASV_IP",
     "CURLOPT_FTP_FILEMETHOD", "CURLOPT_LOCALPORT",     "CURLOPT_LOCALPORTRANGE",
+    "CURLOPT_MAX_SEND_SPEED_LARGE",                    "CURLOPT_MAX_RECV_SPEED_LARGE",
+    "CURLOPT_FTP_ALTERNATIVE_TO_USER",                 "CURLOPT_SSL_SESSIONID_CACHE",
+    "CURLOPT_SSH_AUTH_TYPES",                          "CURLOPT_SSH_PUBLIC_KEYFILE",
+    "CURLOPT_SSH_PRIVATE_KEYFILE",                     "CURLOPT_TIMEOUT_MS",
+    "CURLOPT_CONNECTTIMEOUT_MS",                       "CURLOPT_HTTP_CONTENT_DECODING",
+    "CURLOPT_HTTP_TRANSFER_DECODING",
     (char *) NULL
 };
 
@@ -248,6 +252,11 @@ static CONST char *configTable[] = {
     "-ignorecontentlength",                      "-cookielist",
     "-ftpskippasvip",     "-ftpfilemethod",      "-localport",
     "-localportrange",
+    "-maxsendspeed",                             "-maxrecvspeed",
+    "-ftpalternativetouser",                     "-sslsessionidcache",
+    "-sshauthtypes",      "-sshpublickeyfile",   "-sshprivatekeyfile",
+    "-timeoutms",         "-connecttimeoutms",   "-contentdecoding",
+    "-transferdecoding",
     (char *) NULL
 };
 
@@ -256,11 +265,6 @@ static CONST char    *timeCond[] = {
     (char *) NULL
 };
 
-static CONST char    *closePolicy[]={
-    "oldest", "leastrecentlyused", "leasttraffic", "slowest",
-    (char *) NULL
-};
-
 static CONST char    *getInfoTable[]={
     "effectiveurl",   "httpcode",       "responsecode",
     "filetime",       "totaltime",      "namelookuptime",
@@ -272,6 +276,7 @@ static CONST char    *getInfoTable[]={
     "redirecttime",   "redirectcount",  "httpauthavail",
     "proxyauthavail", "oserrno",        "numconnects",
     "sslengines",     "httpconnectcode","cookielist",
+    "ftpentrypath",
     (char *) NULL
 };
 
@@ -326,6 +331,10 @@ static CONST char *ftpsslauth[] = {
     "default", "ssl", "tls", (char *)NULL
 };
 
+static CONST char *ftpsslccc[] = {
+    "none", "passive", "active", (char *)NULL
+};
+
 static CONST char *sslversion[] = {
     "default", "tlsv1", "sslv2", "sslv3", (char *)NULL
 };
@@ -334,6 +343,10 @@ static CONST char *ftpfilemethod[] = {
     "default", "multicwd", "nocwd", "singlecwd", (char *)NULL
 };
 
+static CONST char *sshauthtypes[] = {
+    "publickey", "password", "host", "keyboard", "any", (char *)NULL
+};
+
 static curlioerr curlioctl(CURL *handle, curliocmd cmd, void *userp);
 
 int Tclcurl_MultiInit (Tcl_Interp *interp);
@@ -370,6 +383,8 @@ int SetoptInt(Tcl_Interp *interp,CURL *curlHandle,CURLoption opt,int tableIndex,
             Tcl_Obj *tclObj);
 int SetoptLong(Tcl_Interp *interp,CURL *curlHandle,CURLoption opt,int tableIndex,
             Tcl_Obj *tclObj);
+int SetoptCurlOffT(Tcl_Interp *interp,CURL *curlHandle,CURLoption opt,int tableIndex,
+            Tcl_Obj *tclObj);
 int SetoptChar(Tcl_Interp *interp,char **charPtr,CURL *curlHandle,CURLoption opt,
             int tableIndex,Tcl_Obj *tclObj);
 int SetoptSHandle(Tcl_Interp *interp,CURL *curlHandle,CURLoption opt,
@@ -380,7 +395,7 @@ CURLcode curlGetInfo(Tcl_Interp *interp,CURL *curlHandle,int tableIndex);
 
 void curlFreeSpace(struct curlObjData *curlData);
 
-void curlErrorSetOpt(Tcl_Interp *interp, int option, CONST char *parPtr);
+void curlErrorSetOpt(Tcl_Interp *interp,CONST char **configTable, int option, CONST char *parPtr);
 
 size_t curlHeaderReader(void *ptr,size_t size,size_t nmemb,FILE *stream);
 
