@@ -18,6 +18,12 @@ proc DebugProc {infoType data} {
         4 {
             set type "outgoing data"
         }
+        5 {
+            set type "incoming SSL data"
+        }
+        6 {
+            set type "outgoing SSL data"
+        }
     }
 
     puts "Type: $type - Data:"
@@ -31,15 +37,6 @@ set curlHandle [curl::init]
 $curlHandle configure -url 127.0.0.1 -verbose 1 \
         -debugproc DebugProc
 
-
 $curlHandle perform
-
-
+puts Adios
 $curlHandle cleanup
-
-
-
-
-
-
-
